'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.checkInput = checkInput;
exports.default = pptx2pdf;

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fs = require('mz/fs');

var _fs2 = _interopRequireDefault(_fs);

var _child_process = require('mz/child_process');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function checkInput(inputPath, inputType) {
  return new Promise(function (resolve, reject) {
    if (!(inputType === 'pptx' || inputType === 'pdf')) return reject('Must be pptx or pdf');

    var ext = _path2.default.extname(inputPath);

    if (ext === '.pdf' && inputType === 'pdf') return resolve(true);

    var pptxExtensions = ['.pptx', '.ppt', '.odp'];

    if (inputType === 'pptx' && pptxExtensions.includes(ext)) return resolve(true);

    if (inputType === 'pdf') return reject('File type of pdf, extension must be pdf');

    if (inputType === 'pptx') return reject('File type of pptx, extension must be pptx, ppt or odp');
  });
}

function pptx2pdf(_ref) {
  var input = _ref.input,
      inputType = _ref.inputType,
      outputDir = _ref.outputDir,
      filename = _ref.filename,
      target = _ref.target,
      png = _ref.png,
      removePdf = _ref.removePdf,
      libreofficeBin = _ref.libreofficeBin,
      convertBin = _ref.convertBin;

  // export default function pptx2pdf(options) {
  //   const { input, inputType, outputDir, filename, target, png, removePdf, libreofficeBin, convertBin } = options;
  // console.log(options);

  var defaultLibreoffice = process.platform === 'darwin' ? '/Applications/LibreOffice.app/Contents/MacOS/soffice' : '/usr/bin/libreoffice';

  var libreoffice = libreofficeBin || defaultLibreoffice;

  var convert = 'convert';

  var inputPath = input || target;
  var outputFile = filename || _path2.default.basename(inputPath).replace(/\..*$/, '.pdf');
  var outputPath = outputDir + '/' + outputFile;
  var cmdPdf = libreoffice + ' --headless --invisible --convert-to pdf --outdir ' + outputDir + ' ' + inputPath;
  var cmdPng = convert + ' -resize 1200 -density 200  ' + outputPath + ' ' + outputPath.replace(/\.pdf$/, '') + '.png';
  var cmdPdf2Png = convert + ' -resize 1200 -density 200  ' + inputPath + ' ' + inputPath.replace(/\.pdf$/, '') + '.png';

  return _fs2.default.access(inputPath).then(function () {
    return checkInput(inputPath, inputType);
  }).then(function () {

    if (inputType === 'pdf') return (0, _child_process.exec)(cmdPdf2Png);

    return (0, _child_process.exec)(cmdPdf).then(function () {
      if (!png) {
        return _fs2.default.access(outputPath);
      } else {
        return (0, _child_process.exec)(cmdPng).then(function () {
          if (removePdf) _fs2.default.unlink(outputPath);
        });
      }
    });
  });
}